4-Class motor imagery — BCI-Framework documentation

# 4-Class motor imagery

class `bci_framework.default_extensions.Class_motor_imagery.main.` `FourClassMotorImagery`

  Classic arrow cues for motor imagery.

  `build_trials`() → None

    Define the trials and pipeline trials.

    The trials consist (in this case) in a list of cues. The pipeline trials is a set of couples (callable, duration) that define a single trial, this list of functions are executed asynchronously and repeated for each trial.

  `soa`(*args) → None

    Stimulus onset asynchronously.

    This is a pipeline method, that explains the unused *args arguments.

  `start`() → None

    Start the run.

    A run consist in a consecutive trials execution.

  `stop`() → None

    Stop pipeline execution.

  `stop_run`() → None

    Stop pipeline execution.

  `synchronizer`(value: bool) → None

    Show or hide synchronizer.

  `trial`(cue: Literal[Right, Left, Up, Bottom]) → None

    Cue visualization.

    This is a pipeline method, that means it receives the respective trial as argument each time is called.